@@ -1,6 +1,7 @@
 
 import os.path
 
+from django.conf import settings
 from django.utils.translation import ugettext as _
 
 from mezzanine.conf import register_setting
@@ -11,8 +12,8 @@ register_setting(
     description=_("Controls the ordering and grouping of the admin menu."),
     editable=False,
     default=(
-        (_("Content"), ("pages.Page", "blog.BlogPost", "blog.Comment",
-            (_("Media Library"), "fb_browse"),)),
+        (_("Content"), ("pages.Page", "blog.BlogPost",
+           "generic.ThreadedComment", (_("Media Library"), "fb_browse"),)),
         (_("Site"), ("sites.Site", "redirects.Redirect", "conf.Setting")),
         (_("Users"), ("auth.User", "auth.Group",)),
     ),
@@ -27,6 +28,7 @@ register_setting(
 
 register_setting(
     name="BLOG_BITLY_USER",
+    label=_("bit.ly username"),
     description=_("Username for bit.ly URL shortening service."),
     editable=True,
     default="",
@@ -34,6 +36,7 @@ register_setting(
 
 register_setting(
     name="BLOG_BITLY_KEY",
+    label=_("bit.ly key"),
     description=_("Key for bit.ly URL shortening service."),
     editable=True,
     default="",
@@ -41,6 +44,7 @@ register_setting(
 
 register_setting(
     name="BLOG_POST_PER_PAGE",
+    label=_("Blog posts per page"),
     description=_("Number of blog posts to show on a blog listing page."),
     editable=True,
     default=5,
@@ -48,6 +52,7 @@ register_setting(
 
 register_setting(
     name="BLOG_POST_MAX_PAGING_LINKS",
+    label=_("Max blog paging links"),
     description=_("Max number of paging links to show on a blog listing page."),
     editable=True,
     default=10,
@@ -62,20 +67,15 @@ register_setting(
 
 register_setting(
     name="COMMENTS_DISQUS_SHORTNAME",
-    description=_("Username for the http://disqus.com comments service."),
-    editable=True,
-    default="",
-)
-
-register_setting(
-    name="COMMENTS_DISQUS_KEY",
-    description=_("API key for the http://disqus.com comments service."),
+    label=_("Disqus shortname"),
+    description=_("Shortname for the http://disqus.com comments service."),
     editable=True,
     default="",
 )
 
 register_setting(
     name="COMMENTS_DEFAULT_APPROVED",
+    label=_("Auto-approve comments"),
     description=_("If ``True``, built-in comments are approved by default."),
     editable=True,
     default=True,
@@ -83,6 +83,7 @@ register_setting(
 
 register_setting(
     name="COMMENTS_NUM_LATEST",
+    label=_("Admin comments"),
     description=_("Number of latest comments to show in the admin dashboard."),
     editable=True,
     default=5,
@@ -90,11 +91,19 @@ register_setting(
 
 register_setting(
     name="COMMENTS_UNAPPROVED_VISIBLE",
-    description=_("If ``True``, unapproved comments will have a placeholder "
-        "visible on the site with a 'waiting for approval' or "
-        "'comment removed' message based on the workflow around the "
-        "``COMMENTS_DEFAULT_APPROVED`` setting - if ``True`` then "
-        "the former message is used, if ``False`` then the latter."),
+    label=_("Show unapproved comments"),
+    description=_("If ``True``, comments that have ``is_public`` unchecked "
+        "will still be displayed, but replaced with a ``waiting to be "
+        "approved`` message."),
+    editable=True,
+    default=True,
+)
+
+register_setting(
+    name="COMMENTS_REMOVED_VISIBLE",
+    label=_("Show removed comments"),
+    description=_("If ``True``, comments that have ``removed`` checked "
+        "will still be displayed, but replaced with a ``removed`` message."),
     editable=True,
     default=True,
 )
@@ -113,20 +122,29 @@ register_setting(
     default="/content_media/",
 )
 
+if "mezzanine.blog" in settings.INSTALLED_APPS:
+    dashboard_tags = (
+        ("blog_tags.quick_blog", "mezzanine_tags.app_list"),
+        ("comment_tags.recent_comments",),
+        ("mezzanine_tags.recent_actions",),
+    )
+else:
+    dashboard_tags = (
+        ("mezzanine_tags.app_list",),
+        ("mezzanine_tags.recent_actions",),
+        (),
+    )
+
 register_setting(
     name="DASHBOARD_TAGS",
     description=_("A three item sequence, each containing a sequence of "
         "template tags used to render the admin dashboard."),
     editable=False,
-    default=(
-        ("blog_tags.quick_blog", "mezzanine_tags.app_list"),
-        ("blog_tags.recent_comments",),
-        ("mezzanine_tags.recent_actions",),
-    ),
+    default=dashboard_tags,
 )
 
 register_setting(
-    name="DEFAULT_DEVICE",
+    name="DEVICE_DEFAULT",
     description=_("Device specific template sub-directory to use as the "
         "default device."),
     editable=False,
@@ -177,6 +195,14 @@ register_setting(
     default=False,
 )
 
+register_setting(
+    name="FORMS_CSV_DELIMITER",
+    description=_("Char to use as a field delimiter when exporting form "
+        "responses as CSV."),
+    editable=False,
+    default=",",
+)
+
 register_setting(
     name="FORMS_UPLOAD_ROOT",
     description=_("Absolute path for storing file uploads for the forms app."),
@@ -186,21 +212,23 @@ register_setting(
 
 register_setting(
     name="GOOGLE_ANALYTICS_ID",
+    label=_("Google Analytics ID"),
     editable=True,
     description=_("Google Analytics ID (http://www.google.com/analytics/)"),
     default="",
 )
 
 register_setting(
-    name="HTML_WIDGET_CLASS",
+    name="RICHTEXT_WIDGET_CLASS",
     description=_("Dotted package path and class name of the widget to use "
-        "for the ``HtmlField``."),
+        "for the ``RichTextField``."),
     editable=False,
     default="mezzanine.core.forms.TinyMceWidget",
 )
 
 register_setting(
     name="TAG_CLOUD_SIZES",
+    label=_("Tag Cloud Sizes"),
     description=_("Number of different sizes for tags when shown as a cloud."),
     editable=True,
     default=4,
@@ -222,8 +250,23 @@ register_setting(
     default=True,
 )
 
+register_setting(
+    name="RATINGS_MIN",
+    description=_("Min value for a rating."),
+    editable=False,
+    default=1,
+)
+
+register_setting(
+    name="RATINGS_MAX",
+    description=_("Max value for a rating."),
+    editable=False,
+    default=5,
+)
+
 register_setting(
     name="SEARCH_PER_PAGE",
+    label=_("Search results per page"),
     description=_("Number of results to show in the search results page."),
     editable=True,
     default=10,
@@ -231,11 +274,29 @@ register_setting(
 
 register_setting(
     name="SEARCH_MAX_PAGING_LINKS",
+    label=_("Max search paging links"),
     description=_("Max number of paging links for the search results page."),
     editable=True,
     default=10,
 )
 
+register_setting(
+    name="SITE_TITLE",
+    label=_("Site Title"),
+    description=_("Title that will display at the top of the site, and be "
+        "appended to the content of the HTML title tags on every page."),
+    editable=True,
+    default="Mezzanine",
+)
+
+register_setting(
+    name="SITE_TAGLINE",
+    label=_("Tagline"),
+    description=_("A tag line that will appear at the top of all pages."),
+    editable=True,
+    default=_("An open source content management platform."),
+)
+
 register_setting(
     name="STOP_WORDS",
     description=_("List of words which will be stripped from search queries."),
@@ -297,9 +358,26 @@ register_setting(
     name="TEMPLATE_ACCESSIBLE_SETTINGS",
     description=_("Sequence of setting names available within templates."),
     editable=False,
-    default=("BLOG_BITLY_USER", "BLOG_BITLY_KEY", "COMMENTS_DEFAULT_APPROVED",
-        "COMMENTS_DISQUS_KEY", "COMMENTS_DISQUS_SHORTNAME",
-        "COMMENTS_NUM_LATEST", "CONTENT_MEDIA_URL", "DEV_SERVER",
-        "FORMS_USE_HTML5", "GOOGLE_ANALYTICS_ID", "PAGES_MENU_SHOW_ALL",
+    default=(
+        "BLOG_BITLY_USER", "BLOG_BITLY_KEY",
+        "COMMENTS_DISQUS_SHORTNAME", "COMMENTS_NUM_LATEST",
+        "CONTENT_MEDIA_URL", "DEV_SERVER", "FORMS_USE_HTML5",
+        "GRAPPELLI_INSTALLED", "GOOGLE_ANALYTICS_ID",
+        "PAGES_MENU_SHOW_ALL", "SITE_TITLE", "SITE_TAGLINE",
+        "RATINGS_MAX",
     ),
 )
+
+# The following settings are defined here for documentation purposes
+# as this file is used to auto-generate the documentation for all
+# available settings. They are Mezzanine specific, but their values
+# are *always* overridden by the project's settings or local_settings
+# modules, so the default values defined here will never be used.
+
+register_setting(
+    name="USE_SOUTH",
+    description=_("If ``True``, the south application will be "
+        "automatically added to the ``INSTALLED_APPS`` setting."),
+    editable=False,
+    default=False,
+)
