@@ -9,14 +9,12 @@ from mezzanine.core.models import Orderable
 from mezzanine.utils.urls import content_media_urls, admin_url
 
 
-# Build the list of admin JS file for ``Displayable`` models.
 # For >= Django 1.2 include a backport of collapse.js which targets
 # earlier versions of the admin.
-displayable_js = ["js/jquery-1.4.4.min.js", "js/keywords_field.js"]
 from django import VERSION
-if not (VERSION[0] <= 1 and VERSION[1] <= 1):
-    displayable_js.append("js/collapse_backport.js")
-displayable_js = content_media_urls(*displayable_js)
+displayable_js = []
+if VERSION > (1, 1, 0):
+    displayable_js = content_media_urls("js/collapse_backport.js")
 
 
 class DisplayableAdmin(admin.ModelAdmin):
@@ -41,20 +39,13 @@ class DisplayableAdmin(admin.ModelAdmin):
             "classes": ("collapse-closed",)},),
     )
 
-    def save_model(self, request, obj, form, change):
-        """
-        Store the keywords as a single string into the ``_keywords`` field
-        for convenient access when searching.
-        """
-        obj = form.save(commit=True)
-        obj.set_searchable_keywords()
-
 
 class DynamicInlineAdmin(admin.TabularInline):
     """
-    Admin inline that uses JS to inject an "Add another" link when when
-    clicked, dynamically reveals another fieldset. Also handles adding the
-    ``_order`` field and its widget for models that subclass ``Orderable``.
+    Admin inline that uses JS to inject an "Add another" link which
+    when clicked, dynamically reveals another fieldset. Also handles
+    adding the ``_order`` field and its widget for models that
+    subclass ``Orderable``.
     """
 
     form = DynamicInlineAdminForm
@@ -78,10 +69,10 @@ class DynamicInlineAdmin(admin.TabularInline):
 
 class OwnableAdmin(admin.ModelAdmin):
     """
-    Admin class for models that subclass the abstract ``Ownable`` model.
-    Handles limiting the change list to objects owned by the logged in user,
-    as well as setting the owner of newly created objects to the logged in
-    user.
+    Admin class for models that subclass the abstract ``Ownable``
+    model. Handles limiting the change list to objects owned by the
+    logged in user, as well as setting the owner of newly created \
+    objects to the logged in user.
     """
 
     def save_form(self, request, form, change):
@@ -95,7 +86,8 @@ class OwnableAdmin(admin.ModelAdmin):
 
     def queryset(self, request):
         """
-        Filter the change list by currently logged in user if not a superuser.
+        Filter the change list by currently logged in user if not a
+        superuser.
         """
         qs = super(OwnableAdmin, self).queryset(request)
         if request.user.is_superuser:
@@ -105,9 +97,9 @@ class OwnableAdmin(admin.ModelAdmin):
 
 class SingletonAdmin(admin.ModelAdmin):
     """
-    Admin class for models that should only contain a single instance in the
-    database. Redirect all views to the change view when the instance exists,
-    and to the add view when it doesn't.
+    Admin class for models that should only contain a single instance
+    in the database. Redirect all views to the change view when the
+    instance exists, and to the add view when it doesn't.
     """
 
     def add_view(self, *args, **kwargs):
@@ -124,8 +116,8 @@ class SingletonAdmin(admin.ModelAdmin):
 
     def changelist_view(self, *args, **kwargs):
         """
-        Redirect to the add view if no records exist or the change view if
-        the singleton instance exists.
+        Redirect to the add view if no records exist or the change
+        view if the singleton instance exists.
         """
         try:
             singleton = self.model.objects.get()
@@ -153,4 +145,4 @@ class SingletonAdmin(admin.ModelAdmin):
         else:
             extra_context["singleton"] = True
         return super(SingletonAdmin, self).change_view(request, object_id,
-                                                        extra_context)
+                                                       extra_context)
