@@ -12,7 +12,7 @@ from django.utils.simplejson import loads
 from django.utils.text import capfirst
 
 from mezzanine.conf import settings
-from mezzanine.core.fields import HtmlField
+from mezzanine.core.fields import RichTextField
 from mezzanine.core.forms import get_edit_form
 from mezzanine.utils.html import decode_entities
 from mezzanine.utils.views import is_editable
@@ -133,7 +133,7 @@ def editable_loader(context):
     t = get_template("includes/editable_toolbar.html", context)
     context["REDIRECT_FIELD_NAME"] = REDIRECT_FIELD_NAME
     context["toolbar"] = t.render(Context(context))
-    context["html_editor_js"] = HtmlField().formfield().widget.Media.js
+    context["html_editor_js"] = RichTextField().formfield().widget.Media.js
     return context
 
 
@@ -162,7 +162,7 @@ def editable(parsed, context, token):
             parsed = "".join([unicode(getattr(*field)) for field in fields])
         except AttributeError:
             pass
-    if fields:
+    if fields and "request" in context:
         obj = fields[0][0]
         if isinstance(obj, Model) and is_editable(obj, context["request"]):
             field_names = ",".join([f[1] for f in fields])
@@ -233,8 +233,7 @@ def admin_app_list(request):
                     app_dict[app_title]["models"].append(model_dict)
                 else:
                     try:
-                        titles = [x[0] for x in
-                            settings.ADMIN_MENU_ORDER]
+                        titles = [x[0] for x in settings.ADMIN_MENU_ORDER]
                         index = titles.index(app_title)
                     except ValueError:
                         index = None
