@@ -1,19 +1,26 @@
 
 from django.contrib.auth.models import User
+from django.contrib.contenttypes.models import ContentType
 from django.core.urlresolvers import reverse
 from django.db import connection
 from django.template import Context, Template, TemplateDoesNotExist
 from django.template.loader import get_template
 from django.test import TestCase
+from django.utils.html import strip_tags
+from django.contrib.sites.models import Site
 
-from mezzanine.blog.models import BlogPost, Comment
+from mezzanine.blog.models import BlogPost
 from mezzanine.conf import settings, registry
 from mezzanine.conf.models import Setting
 from mezzanine.core.models import CONTENT_STATUS_DRAFT
 from mezzanine.core.models import CONTENT_STATUS_PUBLISHED
 from mezzanine.forms import fields
 from mezzanine.forms.models import Form
-from mezzanine.pages.models import ContentPage
+from mezzanine.generic.forms import RatingForm
+from mezzanine.generic.models import ThreadedComment, AssignedKeyword, Keyword
+from mezzanine.generic.models import RATING_RANGE
+
+from mezzanine.pages.models import RichTextPage
 from mezzanine.utils.tests import run_pyflakes_for_package
 from mezzanine.utils.importing import import_dotted_path
 
@@ -39,7 +46,7 @@ class Tests(TestCase):
         Test a draft page as only being viewable by a staff member.
         """
         self.client.logout()
-        draft = ContentPage.objects.create(title="Draft",
+        draft = RichTextPage.objects.create(title="Draft",
                                            status=CONTENT_STATUS_DRAFT)
         response = self.client.get(draft.get_absolute_url())
         self.assertEqual(response.status_code, 404)
@@ -49,26 +56,27 @@ class Tests(TestCase):
 
     def test_overridden_page(self):
         """
-        Test that a page with a slug matching a non-page urlpattern 
-        return ``True`` for its overridden property. The blog page from 
+        Test that a page with a slug matching a non-page urlpattern
+        return ``True`` for its overridden property. The blog page from
         the fixtures should satisfy this case.
         """
-        blog_page, created = ContentPage.objects.get_or_create(
+        blog_page, created = RichTextPage.objects.get_or_create(
                                                 slug=settings.BLOG_SLUG)
         self.assertTrue(blog_page.overridden())
 
     def test_description(self):
         """
-        Test generated description is first line of content.
+        Test generated description is text version of the first line
+        of content.
         """
         description = "<p>How now brown cow</p>"
-        page = ContentPage.objects.create(title="Draft",
+        page = RichTextPage.objects.create(title="Draft",
                                           content=description * 3)
-        self.assertEqual(page.description, description)
+        self.assertEqual(page.description, strip_tags(description))
 
     def test_device_specific_template(self):
         """
-        Test that an alternate template is rendered when a mobile 
+        Test that an alternate template is rendered when a mobile
         device is used.
         """
         try:
@@ -92,9 +100,26 @@ class Tests(TestCase):
         response = self.client.get(blog_post.get_absolute_url())
         self.assertEqual(response.status_code, 200)
 
+    def test_rating(self):
+        """
+        Test that ratings can be posted and avarage/count are calculated.
+        """
+        blog_post = BlogPost.objects.create(title="Ratings", user=self._user,
+                                            status=CONTENT_STATUS_PUBLISHED)
+        data = RatingForm(blog_post).initial
+        for value in RATING_RANGE:
+            data["value"] = value
+            response = self.client.post(reverse("rating"), data=data)
+            response.delete_cookie("mezzanine-rating")
+        blog_post = BlogPost.objects.get(id=blog_post.id)
+        count = len(RATING_RANGE)
+        average = sum(RATING_RANGE) / float(count)
+        self.assertEqual(blog_post.rating_count, count)
+        self.assertEqual(blog_post.rating_average, average)
+
     def queries_used_for_template(self, template, **context):
         """
-        Return the number of queries used when rendering a template 
+        Return the number of queries used when rendering a template
         string.
         """
         settings.DEBUG = True
@@ -121,63 +146,86 @@ class Tests(TestCase):
 
     def test_comments(self):
         """
-        Test that rendering the blog comments executes the same number 
-        of queries regardless of the number of nested replies.
+        Test that rendering comments executes the same number of
+        queries, regardless of the number of nested replies.
         """
         blog_post = BlogPost.objects.create(title="Post", user=self._user)
-        template = "{% load blog_tags %}{% blog_comments_for blog_post %}"
+        content_type = ContentType.objects.get_for_model(blog_post)
+        kwargs = {"content_type": content_type, "object_pk": blog_post.id,
+                  "site_id": settings.SITE_ID}
+        template = "{% load comment_tags %}{% comment_thread blog_post %}"
         before = self.queries_used_for_template(template, blog_post=blog_post)
-        self.create_recursive_objects(Comment, "replied_to", name="Comment",
-                                      blog_post=blog_post)
+        self.create_recursive_objects(ThreadedComment, "replied_to", **kwargs)
         after = self.queries_used_for_template(template, blog_post=blog_post)
         self.assertEquals(before, after)
 
     def test_page_menu(self):
         """
-        Test that rendering a page menu executes the same number of 
-        queries regardless of the number of pages or levels of 
+        Test that rendering a page menu executes the same number of
+        queries regardless of the number of pages or levels of
         children.
         """
-        template = ('{% load pages_tags %}' 
-                    '{% page_menu "pages/menus/tree.html" %}') 
+        template = ('{% load pages_tags %}'
+                    '{% page_menu "pages/menus/tree.html" %}')
         before = self.queries_used_for_template(template)
-        self.create_recursive_objects(ContentPage, "parent", title="Page",
+        self.create_recursive_objects(RichTextPage, "parent", title="Page",
                                       status=CONTENT_STATUS_PUBLISHED)
         after = self.queries_used_for_template(template)
         self.assertEquals(before, after)
 
+    def test_keywords(self):
+        """
+        Test that the keywords_string field is correctly populated.
+        """
+        page = RichTextPage.objects.create(title="test keywords")
+        keywords = set(["how", "now", "brown", "cow"])
+        page.keywords = [AssignedKeyword(
+                         keyword_id=Keyword.objects.get_or_create(title=k)[0].id)
+                         for k in keywords]
+        page = RichTextPage.objects.get(id=page.id)
+        self.assertEquals(keywords, set(page.keywords_string.split(" ")))
+
     def test_search(self):
         """
         Test search.
         """
-        ContentPage.objects.all().delete()
-        first = ContentPage.objects.create(title="test page").id
-        second = ContentPage.objects.create(title="test another test page").id
+        RichTextPage.objects.all().delete()
+        published = {"status": CONTENT_STATUS_PUBLISHED}
+        first = RichTextPage.objects.create(title="test page",
+                                           status=CONTENT_STATUS_DRAFT).id
+        second = RichTextPage.objects.create(title="test another test page",
+                                            **published).id
+        # Draft shouldn't be a result.
+        results = RichTextPage.objects.search("test")
+        self.assertEqual(len(results), 1)
+        RichTextPage.objects.filter(id=first).update(**published)
+        results = RichTextPage.objects.search("test")
+        self.assertEqual(len(results), 2)
         # Either word.
-        results = ContentPage.objects.search("another test")
+        results = RichTextPage.objects.search("another test")
         self.assertEqual(len(results), 2)
         # Must include first word.
-        results = ContentPage.objects.search("+another test")
+        results = RichTextPage.objects.search("+another test")
         self.assertEqual(len(results), 1)
         # Mustn't include first word.
-        results = ContentPage.objects.search("-another test")
+        results = RichTextPage.objects.search("-another test")
         self.assertEqual(len(results), 1)
         if results:
             self.assertEqual(results[0].id, first)
         # Exact phrase.
-        results = ContentPage.objects.search('"another test"')
+        results = RichTextPage.objects.search('"another test"')
         self.assertEqual(len(results), 1)
         if results:
             self.assertEqual(results[0].id, second)
         # Test ordering.
-        results = ContentPage.objects.search("test")
+        results = RichTextPage.objects.search("test")
         self.assertEqual(len(results), 2)
         if results:
             self.assertEqual(results[0].id, second)
 
     def test_forms(self):
         """
-        Simple 200 status check against rendering and posting to forms 
+        Simple 200 status check against rendering and posting to forms
         with both optional and required fields.
         """
         for required in (True, False):
@@ -195,9 +243,9 @@ class Tests(TestCase):
 
     def test_settings(self):
         """
-        Test that an editable setting can be overridden with a DB 
-        value and that the data type is preserved when the value is 
-        returned back out of the DB. Also checks to ensure no 
+        Test that an editable setting can be overridden with a DB
+        value and that the data type is preserved when the value is
+        returned back out of the DB. Also checks to ensure no
         unsupported types are defined for editable settings.
         """
         # Find an editable setting for each supported type.
@@ -246,3 +294,76 @@ class Tests(TestCase):
         except ImportError:
             self.fail("mezzanine.utils.imports.import_dotted_path"
                       "could not import \"mezzanine.core\"")
+
+    def _create_page(self, title, status):
+        return RichTextPage.objects.create(title=title, status=status)
+
+    def _test_site_pages(self, title, status, count):
+        # test _default_manager
+        pages = RichTextPage._default_manager.all()
+        self.assertEqual(pages.count(), count)
+        self.assertTrue(title in [page.title for page in pages])
+
+        # test objects manager
+        pages = RichTextPage.objects.all()
+        self.assertEqual(pages.count(), count)
+        self.assertTrue(title in [page.title for page in pages])
+
+        # test response status code
+        code = 200 if status == CONTENT_STATUS_PUBLISHED else 404
+        pages = RichTextPage.objects.filter(status=status)
+        response = self.client.get(pages[0].get_absolute_url())
+        self.assertEqual(response.status_code, code)
+
+    def test_mulisite(self):
+        from django.conf import settings
+
+        # setup
+        try:
+            old_site_id = settings.SITE_ID
+        except:
+            old_site_id = None
+
+        site1 = Site.objects.create(domain="site1.com")
+        site2 = Site.objects.create(domain="site2.com")
+
+        # create pages under site1, which should be only accessible when SITE_ID is site1
+        settings.SITE_ID = site1.pk
+        site1_page = self._create_page("Site1 Test", CONTENT_STATUS_PUBLISHED)
+        self._test_site_pages("Site1 Test", CONTENT_STATUS_PUBLISHED, count=1)
+
+        # create pages under site2, which should only be accessible when SITE_ID is site2
+        settings.SITE_ID = site2.pk
+        self._create_page("Site2 Test", CONTENT_STATUS_PUBLISHED)
+        self._test_site_pages("Site2 Test", CONTENT_STATUS_PUBLISHED, count=1)
+
+        # original page should 404
+        response = self.client.get(site1_page.get_absolute_url())
+        self.assertEqual(response.status_code, 404)
+
+        # change back to site1, and only the site1 pages should be retrieved
+        settings.SITE_ID = site1.pk
+        self._test_site_pages("Site1 Test", CONTENT_STATUS_PUBLISHED, count=1)
+
+        # insert a new record, see the count change
+        self._create_page("Site1 Test Draft", CONTENT_STATUS_DRAFT)
+        self._test_site_pages("Site1 Test Draft", CONTENT_STATUS_DRAFT, count=2)
+        self._test_site_pages("Site1 Test Draft", CONTENT_STATUS_PUBLISHED, count=2)
+
+        # change back to site2, and only the site2 pages should be retrieved
+        settings.SITE_ID = site2.pk
+        self._test_site_pages("Site2 Test", CONTENT_STATUS_PUBLISHED, count=1)
+
+        # insert a new record, see the count change
+        self._create_page("Site2 Test Draft", CONTENT_STATUS_DRAFT)
+        self._test_site_pages("Site2 Test Draft", CONTENT_STATUS_DRAFT, count=2)
+        self._test_site_pages("Site2 Test Draft", CONTENT_STATUS_PUBLISHED, count=2)
+
+        # tear down
+        if old_site_id:
+            settings.SITE_ID = old_site_id
+        else:
+            del settings.SITE_ID
+
+        site1.delete()
+        site2.delete()
