@@ -3,8 +3,33 @@
 # MEZZANINE SETTINGS #
 ######################
 
+# The following Mezzanine settings are already defined in
+# mezzanine.conf.defaults, but can be uncommented below in
+# order to override their defaults.
+
+# Controls the ordering and grouping of the admin menu.
+# ADMIN_MENU_ORDER = (
+#     (_("Content"), ("pages.Page", "blog.BlogPost",
+#        "generic.ThreadedComment", (_("Media Library"), "fb_browse"),)),
+#     (_("Site"), ("sites.Site", "redirects.Redirect", "conf.Setting")),
+#     (_("Users"), ("auth.User", "auth.Group",)),
+# )
+
+# A three item sequence, each containing a sequence of template tags
+# used to render the admin dashboard.
+# DASHBOARD_TAGS = (
+#     ("blog_tags.quick_blog", "mezzanine_tags.app_list"),
+#     ("blog_tags.recent_comments",),
+#     ("mezzanine_tags.recent_actions",),
+# )
+
 # Name of the current theme to host during theme development.
-THEME = ""
+# THEME = ""
+
+# If True, the south application will be automatically added to the
+# INSTALLED_APPS setting. This setting is not defined in
+# mezzanine.conf.defaults as is the case with the above settings.
+USE_SOUTH = False
 
 
 ########################
@@ -31,8 +56,8 @@ TIME_ZONE = ""
 # http://www.i18nguy.com/unicode/language-identifiers.html
 LANGUAGE_CODE = "en"
 
-# A boolean that turns on/off debug mode. When set to ``True``, stack traces 
-# are displayed for error pages. Should always be set to ``False`` in 
+# A boolean that turns on/off debug mode. When set to ``True``, stack traces
+# are displayed for error pages. Should always be set to ``False`` in
 # production. Best set to ``True`` in local_settings.py
 DEBUG = False
 
@@ -94,8 +119,8 @@ PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))
 # Name of the directory for the project.
 PROJECT_DIRNAME = PROJECT_ROOT.split(os.sep)[-1]
 
-# Every cache key will get prefixed with this value - here we set it to 
-# the name of the directory the project is in to try and use something 
+# Every cache key will get prefixed with this value - here we set it to
+# the name of the directory the project is in to try and use something
 # project specific.
 CACHE_MIDDLEWARE_KEY_PREFIX = PROJECT_DIRNAME
 
@@ -120,6 +145,9 @@ ROOT_URLCONF = "%s.urls" % PROJECT_DIRNAME
 # Don't forget to use absolute paths, not relative paths.
 TEMPLATE_DIRS = (os.path.join(PROJECT_ROOT, "templates"),)
 
+LOGIN_URL = "/admin/"
+LOGIN_REDIRECT_URL = "/admin/"
+
 
 ################
 # APPLICATIONS #
@@ -134,6 +162,7 @@ INSTALLED_APPS = (
     "django.contrib.sites",
     "mezzanine.conf",
     "mezzanine.core",
+    "mezzanine.generic",
     "mezzanine.blog",
     "mezzanine.forms",
     "mezzanine.pages",
@@ -179,7 +208,6 @@ PACKAGE_NAME_GRAPPELLI = "grappelli_safe"
 # These will be added to ``INSTALLED_APPS``, only if available.
 OPTIONAL_APPS = (
     "debug_toolbar",
-    "south",
     "django_extensions",
     PACKAGE_NAME_FILEBROWSER,
     PACKAGE_NAME_GRAPPELLI,
@@ -192,8 +220,8 @@ DEBUG_TOOLBAR_CONFIG = {"INTERCEPT_REDIRECTS": False}
 # LOCAL SETTINGS #
 ##################
 
-# Allow any settings to be defined in local_settings.py which should be 
-# ignored in your version control system allowing for settings to be 
+# Allow any settings to be defined in local_settings.py which should be
+# ignored in your version control system allowing for settings to be
 # defined per machine.
 try:
     from local_settings import *
@@ -205,8 +233,8 @@ except ImportError:
 # DYNAMIC SETTINGS #
 ####################
 
-# set_dynamic_settings() will rewrite globals based on what has been 
-# defined so far, in order to provide some better defaults where 
+# set_dynamic_settings() will rewrite globals based on what has been
+# defined so far, in order to provide some better defaults where
 # applicable.
 from mezzanine.utils.conf import set_dynamic_settings
 set_dynamic_settings(globals())
